pub enum Error {
InvalidMapKey,
InvalidInternallyTaggedEnum,
InvalidUsageOfSkip,
}Expand description
Detected a type which Serde is unable to export.
Variants
InvalidMapKey
A map key uses a type that cannot be represented as a Serde map key.
InvalidInternallyTaggedEnum
Internally tagged enum layout is invalid for the encountered enum shape.
InvalidUsageOfSkip
#[specta(skip)] was used in a way that prevents valid serialization.